@@ -755,6 +755,15 @@ xpad_pad_configure_event (XpadPad *pad, GdkEventConfigure *event)
 	
 	save_info (pad);
 	
+	/* Sometimes when moving, if the toolbar tries to hide itself,
+	   the window manager will not resize it correctly.  So, we make
+	   sure not to end the timeout while moving. */
+	if (pad->priv->toolbar_timeout)
+	{
+		g_source_remove (pad->priv->toolbar_timeout);
+		pad->priv->toolbar_timeout = g_timeout_add (1000, (GSourceFunc) toolbar_timeout, pad);
+	}
+	
 	return FALSE;
 }
 
@@ -1000,7 +1009,7 @@ load_info (XpadPad *pad)
 		return;
 	
 	pad->priv->location_valid = TRUE;
-	gtk_window_set_default_size (GTK_WINDOW (pad), pad->priv->width, pad->priv->height);
+	gtk_window_resize (GTK_WINDOW (pad), pad->priv->width, pad->priv->height);
 	gtk_window_move (GTK_WINDOW (pad), pad->priv->x, pad->priv->y);
 	
 	xpad_text_view_set_follow_font_style (XPAD_TEXT_VIEW (pad->priv->textview), follow_font);
